@@ -2,6 +2,9 @@
 
 #define netbsd1 netbsd1         /* we're really close to this */
 #define openbsd openbsd
+#define openbsd3 openbsd3
+#define openbsd4 openbsd4
+#define openbsd5 openbsd5
 #define UVM
 
 #undef MBPOOL_SYMBOL
@@ -16,8 +19,3 @@
 /* define the extra mib modules that are supported */
 #define NETSNMP_INCLUDE_HOST_RESOURCES
 #define NETSNMP_INCLUDE_IFTABLE_REWRITES
-
-#undef INP_NEXT_SYMBOL
-#define INP_NEXT_SYMBOL inp_next
-#undef INP_PREV_SYMBOL
-#define INP_PREV_SYMBOL inp_prev
